﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Set Ref Level /4418,SWPG
DATE:                  2009-12-04
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       108
CONFIGURATION:         Agilent E4418B
CONFIGURATION:         HP 8485A on channel 1
=============================================================================
#
# Procedure Author:
#        DFM
#
# Model(s) Covered:
#        For general purpose use, wherever a leveled microwave signal source
#        (>= 10 MHz) using a Sweep Generator (SWPG) is required.
#
# Compatibility:
#        MET/CAL 7.2 or later
#
# Subprocedures:
#        Sub Apply /SWPG
#
# Required Files:
#        None
#
# Additional Equipment Required:
#        None
#
# The necessary parameters for this procedure are passed from the calling
# procedure.
#
# @TestName   : The name of the test underway, used to notify operator and
#               annotate the test results.
# @CenterFreq : The desired Sweep Generator output frequency.
# @RefLvl     : The desired reference level as measured by the power meter.
# @TestLvl    : The Sweep Generator output level required to generate the
#               specified reference level.
# @Error      : Flag to indicate success or failure of leveling process and
#               facilitate 'bail-out' in the case of the latter.
#
# Example:
# 1.001  M4418  F32   8485A
# 1.002  MATH         @CenterFreq = 300E+6; @RefLvl = -12; @TestLvl = -12
# 1.003  MATH         @TestName = "Third Order Intercept"; @Error = 0
# 1.004  4418         -20.00D                      300MH             RF N  CH1
#
# 1.005  WHILE        ((MEM <= -20.1) || (MEM >= -19.9)) && NOT(@Error)
# 1.006  CALL         Sub Set Ref Level /4418,SWPG
# 1.007  ENDW
#
# 1.008  IF           @Error
# 1.009  EVAL   -e 0 : An error occurred during the [V @TestName] test.
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
# The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
# M4418 statement to allow procedure to compile.
  1.002  M4418  F32   8485A
  1.003  IEEE         [@SWPG]
  1.004  ENDIF

# Compute relative difference between measured value and current output value.
  1.005  MATH         @TestLvl = @RefLvl + (@TestLvl - MEM)

  1.006  IF           (@TestLvl < -100) || (@TestLvl > 20)
  1.007  OPBR         -z Error: Unable to adjust the Sweep Generator output
  1.007  OPBR         [32]      level within its operating range to achieve
  1.007  OPBR         [32]      the desired test level ([V @RefLvl] dBm).
  1.007  OPBR
  1.007  OPBR         [32]      Verify UUT test requirements, SWPG output
  1.007  OPBR         [32]      limits, and connections prior to retrying,
  1.007  OPBR         [32]      if desired.
  1.007  OPBR
  1.007  OPBR         Do you wish to RETRY?
  1.007  OPBR
  1.007  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.007  OPBR         to be terminated.)

  1.008  IF           MEM1
  1.009  MATH         @TestLvl = @RefLvl
  1.010  ELSE
  1.011  MATH         @Error = 1
  1.012  END
  1.013  ENDIF

  1.014  ENDIF

  1.015  MATH         @SWPG_Ampl = @TestLvl & "dBm"
  1.016  CALL         Sub Apply /SWPG
# Pass center frequency (in Hz) from calling procedure to power meter.
  1.017  MATH         MEM = @CenterFreq
# Nominal set to -25 dBm to ensure use with both high and low power sensors.
  1.018  4418         -25.00D                      H                 RF N  CH1

  1.019  END
